==> starplot-0.15.4-py2.py3-none-any.whl: starplot/data/stars.py <==
from functools import cache

import ibis
from ibis import _

from starplot.data import bigsky, DataFiles, db

STAR_NAMES = {
    677: "Alpheratz",
    746: "Caph",
    1067: "Algenib",
    1547: "Citadelle",
    2081: "Ankaa",
    2247: "Felixvarela",
    2920: "Fulu",
    3179: "Schedar",
    3419: "Diphda",
    3479: "Cocibolca",
    3821: "Achird",
    4422: "Castula",
    5054: "Nenque",
    5348: "Wurren",
    5447: "Mirach",
    5529: "Emiw",
    5737: "Revati",
    6193: "Bharani",
    6411: "Adhil",
    6643: "Bélénos",
    6686: "Ruchbah",
    7097: "Alpherg",
    7513: "Titawin",
    7588: "Achernar",
    7607: "Nembus",
    8198: "Torcular",
    8645: "Baten Kaitos",
    8796: "Mothallah",
    8832: "Mesarthim",
    8886: "Segin",
    8903: "Sheratan",
    9487: "Alrescha",
    9640: "Almach",
    9884: "Hamal",
    10826: "Mira",
    11767: "Polaris",
    12191: "Buna",
    12706: "Kaffaljidhma",
    12961: "Koeia",
    13061: "Lilii Borea",
    13192: "Nushagak",
    13268: "Miram",
    13288: "Angetenar",
    13701: "Azha",
    13847: "Acamar",
    13993: "Ayeyarwady",
    14135: "Menkar",
    14576: "Algol",
    14668: "Misam",
    14838: "Botein",
    14879: "Dalim",
    15197: "Zibal",
    15578: "Intan",
    15863: "Mirfak",
    16537: "Ran",
    17096: "Tupi",
    17378: "Rana",
    17448: "Atik",
    17489: "Celaeno",
    17499: "Electra",
    17531: "Taygeta",
    17573: "Maia",
    17579: "Asterope",
    17608: "Merope",
    17702: "Alcyone",
    17847: "Atlas",
    17851: "Pleione",
    18543: "Zaurak",
    18614: "Menkib",
    19587: "Beid",
    19780: "Rhombus",
    19849: "Keid",
    20205: "Prima Hyadum",
    20455: "Secunda Hyadum",
    20535: "Beemim",
    20889: "Ain",
    20894: "Chamukuy",
    21109: "Hoggar",
    21393: "Theemin",
    21421: "Aldebaran",
    21594: "Sceptrum",
    22449: "Tabit",
    22491: "Mouhoun",
    23015: "Hassaleh",
    23416: "Almaaz",
    23453: "Saclateni",
    23767: "Haedus",
    23875: "Cursa",
    24003: "Mago",
    24436: "Rigel",
    24608: "Capella",
    25336: "Bellatrix",
    25428: "Elnath",
    25606: "Nihal",
    25930: "Mintaka",
    25985: "Arneb",
    26207: "Meissa",
    26241: "Hatysa",
    26311: "Alnilam",
    26380: "Bubup",
    26451: "Tianguan",
    26634: "Phact",
    26727: "Alnitak",
    27366: "Saiph",
    27628: "Wazn",
    27989: "Betelgeuse",
    28360: "Menkalinan",
    28380: "Mahasim",
    29034: "Elkurud",
    29550: "Amadioha",
    29655: "Propus",
    30122: "Furud",
    30324: "Mirzam",
    30343: "Tejat",
    30438: "Canopus",
    30860: "Lucilinburhuc",
    30905: "Lusitânia",
    31681: "Alhena",
    31685: "Pipit",
    31895: "Nosaxa",
    32246: "Mebsuta",
    32349: "Sirius",
    32362: "Alzirr",
    32916: "Nervia",
    33579: "Adhara",
    33719: "Citalá",
    33856: "Unurgunite",
    34045: "Muliphein",
    34088: "Mekbuda",
    34444: "Wezen",
    35550: "Wasat",
    35904: "Aludra",
    36188: "Gomeisa",
    36850: "Castor",
    37265: "Jishui",
    37279: "Procyon",
    37284: "Ceibo",
    37826: "Pollux",
    38041: "Tapecue",
    38170: "Azmidi",
    39429: "Naos",
    39757: "Tureis",
    39953: "Regor",  # not officially part of IAU recognized names
    40167: "Tegmine",
    40526: "Tarf",
    40687: "Násti",
    40881: "Piautos",
    41037: "Avior",
    41075: "Alsciaukat",
    41704: "Muscida",
    42402: "Minchir",
    42446: "Gakyid",
    42556: "Meleph",
    42806: "Asellus Borealis",
    42911: "Asellus Australis",
    42913: "Alsephina",
    43109: "Ashlesha",
    43587: "Copernicus",
    43674: "Stribor",
    44066: "Acubens",
    44127: "Talitha",
    44471: "Alkaphrah",
    44816: "Suhail",
    44946: "Nahn",
    45238: "Miaplacidus",
    45556: "Aspidiske",
    45941: "Markeb",
    46390: "Alphard",
    46471: "Intercrus",
    46750: "Alterf",
    47087: "Illyrian",
    47202: "Kalausi",
    47431: "Ukdah",
    47508: "Subra",
    48235: "Natasha",
    48356: "Zhang",
    48455: "Rasalas",
    48615: "Felis",
    48711: "Bibhā",
    49637: "Yunü (Yunu)",
    49669: "Regulus",
    50335: "Adhafera",
    50372: "Tania Borealis",
    50583: "Algieba",
    50801: "Tania Australis",
    51624: "Shaomin",
    52521: "Macondo",
    53229: "Praecipua",
    53721: "Chalawan",
    53740: "Alkes",
    53910: "Merak",
    54061: "Dubhe",
    54158: "Dingolay",
    54872: "Zosma",
    54879: "Chertan",
    55174: "Hunahpú",
    55203: "Alula Australis",
    55219: "Alula Borealis",
    55664: "Shama",
    56211: "Giausar",
    56508: "Formosa",
    56572: "Sagarmatha",
    57291: "Uklun",
    57370: "Flegetonte",
    57399: "Taiyangshou",
    57632: "Denebola",
    57757: "Zavijava",
    57820: "Aniara",
    58001: "Phecda",
    58952: "Tonatiuh",
    59199: "Alchiba",
    59747: "Imai",
    59774: "Megrez",
    59803: "Gienah",
    60129: "Zaniah",
    60260: "Ginan",
    60644: "Tupã",
    60718: "Acrux",
    60965: "Algorab",
    61084: "Gacrux",
    61177: "Funi",
    61317: "Chara",
    61359: "Kraz",
    61394: "Phyllon Kissinou",
    61941: "Porrima",
    62223: "La Superba",
    62423: "Tianyi",
    62434: "Mimosa",
    62956: "Alioth",
    63076: "Taiyi",
    63090: "Minelauva",
    63125: "Cor Caroli",
    63608: "Vindemiatrix",
    64241: "Diadem",
    65378: "Mizar",
    65474: "Spica",
    65477: "Alcor",
    66047: "Dofida",
    66192: "Liesma",
    66249: "Heze",
    67301: "Alkaid",
    67927: "Muphrid",
    68002: "Leepwal",
    68702: "Hadar",
    68756: "Thuban",
    68933: "Menkent",
    69427: "Kang",
    69673: "Arcturus",
    69701: "Syrma",
    69732: "Xuange",
    69974: "Khambalia",
    70755: "Elgafar",
    70890: "Proxima Centauri",
    71075: "Seginus",
    71681: "Toliman",
    71683: "Rigil Kentaurus",
    71860: "Uridim",
    72105: "Izar",
    72339: "Mönch",
    72487: "Merga",
    72607: "Kochab",
    72622: "Zubenelgenubi",
    72845: "Arcalís",
    73136: "Baekdu",
    73555: "Nekkar",
    73714: "Brachium",
    74785: "Zubeneschamali",
    74961: "Nikawiy",
    75097: "Pherkad",
    75411: "Alkalurops",
    75458: "Edasich",
    75695: "Nusakan",
    76267: "Alphecca",
    76333: "Zubenelhakrabi",
    76351: "Karaka",
    77070: "Unukalhai",
    77450: "Gudja",
    78104: "Iklil",
    78265: "Fang",
    78401: "Dschubba",
    78820: "Acrab",
    79043: "Marsic",
    79219: "Kamuy",
    79374: "Jabbah",
    79431: "Sharjah",
    79593: "Yed Prior",
    79882: "Yed Posterior",
    80112: "Alniyat",
    80331: "Athebyne",
    80463: "Cujam",
    80687: "Timir",
    80763: "Antares",
    80816: "Kornephoros",
    80838: "Ogma",
    80883: "Marfik",
    81022: "Rosaliadecastro",
    81266: "Paikauhale",
    82273: "Atria",
    82396: "Larawag",
    82514: "Xamidimura",
    82545: "Pipirima",
    82651: "Mahsati",
    83547: "Rapeto",
    83608: "Alrakis",
    83895: "Aldhibah",
    84012: "Sabik",
    84345: "Rasalgethi",
    84379: "Sarin",
    84405: "Guniibuu",
    84787: "Inquill",
    85670: "Rastaban",
    85693: "Maasym",
    85696: "Lesath",
    85822: "Yildun",
    85927: "Shaula",
    86032: "Rasalhague",
    86228: "Sargas",
    86614: "Dziban",
    86742: "Cebalrai",
    86782: "Alruba",
    86796: "Cervantes",
    87108: "Bake-eo (or Bake Eo)",
    87261: "Fuyue",
    87585: "Grumium",
    87833: "Eltanin",
    87937: "Barnard's Star",
    88414: "Pincoya",
    88635: "Alnasl",
    89341: "Polis",
    89931: "Kaus Media",
    90004: "Alasia",
    90185: "Kaus Australis",
    90344: "Fafnir",
    90496: "Kaus Borealis",
    91262: "Vega",
    91852: "Xihe",
    92420: "Sheliak",
    92761: "Ainalrami",
    92855: "Nunki",
    92895: "Kaveh",
    92946: "Alya",
    93194: "Sulafat",
    93506: "Ascella",
    93747: "Okab",
    94114: "Meridiana",
    94141: "Albaldah",
    94376: "Altais",
    94481: "Aladfar",
    94645: "Gumala",
    95124: "Belel",
    95241: "Arkab Prior",
    95262: "Sika",
    95294: "Arkab Posterior",
    95347: "Rukbat",
    95947: "Albireo",
    96078: "Uruk",
    96100: "Alsafi",
    96757: "Sham",
    97165: "Fawaris",
    97278: "Tarazed",
    97649: "Altair",
    97938: "Libertas",
    98036: "Alshain",
    98066: "Terebellum",
    98823: "Tianfu",
    99473: "Antinous",
    99711: "Phoenicia",
    99894: "Chechia",
    100064: "Algedi",
    100310: "Alshat",
    100345: "Dabih",
    100453: "Sadr",
    100751: "Peacock",
    101421: "Aldulfin",
    101769: "Rotanev",
    101958: "Sualocin",
    102098: "Deneb",
    102488: "Aljanah",
    102618: "Albali",
    103527: "Musica",
    104382: "Polaris Australis",
    104987: "Kitalpha",
    105199: "Alderamin",
    106032: "Alfirk",
    106278: "Sadalsuud",
    106786: "Bunda",
    106824: "Sāmaya",
    106985: "Nashira",
    107136: "Azelfafage",
    107251: "Bosona",
    107259: "Garnet Star",
    107315: "Enif",
    107556: "Deneb Algedi",
    108085: "Aldhanab",
    108375: "Itonda",
    108917: "Kurhah",
    109074: "Sadalmelik",
    109268: "Alnair",
    109427: "Biham",
    110003: "Ancha",
    110130: "Lang-Exster",
    110395: "Sadachbia",
    110813: "Lionrock",
    111169: "Stellio",
    111710: "Situla",
    112029: "Homam",
    112122: "Tiaki",
    112158: "Matar",
    112748: "Sadalbari",
    113136: "Skat",
    113288: "Tengshe",
    113357: "Helvetios",
    113368: "Fomalhaut",
    113881: "Scheat",
    113889: "Fumalsamakah",
    113963: "Markab",
    114322: "Ebla",
    115250: "Salm",
    115623: "Alkarab",
    116076: "Veritate",
    116084: "Poerava",
    116727: "Errai",
    118319: "Axólotl",
}
"""Star names by their HIP id. You can override these values when calling `stars()`"""


class StarCatalog:
    """Built-in star catalogs"""

    BIG_SKY_MAG11 = "big-sky-mag11"
    """
    [Big Sky Catalog](https://github.com/steveberardi/bigsky) ~ 370k stars up to magnitude 10
    
    This is an _abridged_ version of the Big Sky Catalog, including stars up to a limiting magnitude of 10 (total = 368,330 981,852).

    This catalog is included with Starplot, so does not require downloading any files.
    """

    BIG_SKY = "big-sky"
    """
    [Big Sky Catalog](https://github.com/steveberardi/bigsky) ~ 2.5M stars

    This is the full version of the Big Sky Catalog, which includes 2,557,500 stars from Hipparcos, Tycho-1, and Tycho-2.

    This catalog is very large (approx 100 MB), so it's not built-in to Starplot. When you plot stars and specify this catalog, the catalog 
    will be downloaded from the [Big Sky GitHub repository](https://github.com/steveberardi/bigsky) and saved to Starplot's data library 
    directory. You can override this download path with the environment variable `STARPLOT_DOWNLOAD_PATH`
    
    """


@cache
def read_catalog(catalog: StarCatalog = StarCatalog.BIG_SKY_MAG11, table_name="stars"):
    con = db.connect()

    if catalog == StarCatalog.BIG_SKY_MAG11:
        stars = con.read_parquet(DataFiles.BIG_SKY_MAG11, table_name)
    elif catalog == StarCatalog.BIG_SKY:
        bigsky.download_if_not_exists()
        stars = con.read_parquet(DataFiles.BIG_SKY, table_name)
    else:
        raise ValueError("Unrecognized star catalog.")

    designations = con.table("star_designations")

    stars = stars.mutate(
        epoch_year=2000,
        ra=_.ra_degrees,
        dec=_.dec_degrees,
        constellation_id=_.constellation,
        ra_hours=_.ra_degrees / 15,
        # stars parquet does not have geometry field
        geometry=_.ra_degrees.point(_.dec_degrees),
        rowid=ibis.row_number(),
    )

    stars = stars.join(
        designations,
        [
            stars.hip == designations.hip,
            (stars.ccdm == "A") | (stars.ccdm == "") | (stars.ccdm.isnull()),
        ],
        how="left",
    )

    return stars


def load(extent=None, catalog: StarCatalog = StarCatalog.BIG_SKY_MAG11, filters=None):
    filters = filters or []
    stars = read_catalog(catalog)

    if extent:
        stars = stars.filter(stars.geometry.intersects(extent))

    if filters:
        return stars.filter(*filters)

    return stars

==> starplot-0.15.7-py2.py3-none-any.whl: starplot/data/stars.py <==
from functools import cache

import ibis
from ibis import _

from starplot.data import bigsky, DataFiles, db

STAR_NAMES = {
    677: "Alpheratz",
    746: "Caph",
    1067: "Algenib",
    1547: "Citadelle",
    2081: "Ankaa",
    2247: "Felixvarela",
    2920: "Fulu",
    3179: "Schedar",
    3419: "Diphda",
    3479: "Cocibolca",
    3821: "Achird",
    4422: "Castula",
    5054: "Nenque",
    5348: "Wurren",
    5447: "Mirach",
    5529: "Emiw",
    5737: "Revati",
    6193: "Bharani",
    6411: "Adhil",
    6643: "Bélénos",
    6686: "Ruchbah",
    7097: "Alpherg",
    7513: "Titawin",
    7588: "Achernar",
    7607: "Nembus",
    8198: "Torcular",
    8645: "Baten Kaitos",
    8796: "Mothallah",
    8832: "Mesarthim",
    8886: "Segin",
    8903: "Sheratan",
    9487: "Alrescha",
    9640: "Almach",
    9884: "Hamal",
    10826: "Mira",
    11767: "Polaris",
    12191: "Buna",
    12706: "Kaffaljidhma",
    12961: "Koeia",
    13061: "Lilii Borea",
    13192: "Nushagak",
    13268: "Miram",
    13288: "Angetenar",
    13701: "Azha",
    13847: "Acamar",
    13993: "Ayeyarwady",
    14135: "Menkar",
    14576: "Algol",
    14668: "Misam",
    14838: "Botein",
    14879: "Dalim",
    15197: "Zibal",
    15578: "Intan",
    15863: "Mirfak",
    16537: "Ran",
    17096: "Tupi",
    17378: "Rana",
    17448: "Atik",
    17489: "Celaeno",
    17499: "Electra",
    17531: "Taygeta",
    17573: "Maia",
    17579: "Asterope",
    17608: "Merope",
    17702: "Alcyone",
    17847: "Atlas",
    17851: "Pleione",
    18543: "Zaurak",
    18614: "Menkib",
    19587: "Beid",
    19780: "Rhombus",
    19849: "Keid",
    20205: "Prima Hyadum",
    20455: "Secunda Hyadum",
    20535: "Beemim",
    20889: "Ain",
    20894: "Chamukuy",
    21109: "Hoggar",
    21393: "Theemin",
    21421: "Aldebaran",
    21594: "Sceptrum",
    22449: "Tabit",
    22491: "Mouhoun",
    23015: "Hassaleh",
    23416: "Almaaz",
    23453: "Saclateni",
    23767: "Haedus",
    23875: "Cursa",
    24003: "Mago",
    24436: "Rigel",
    24608: "Capella",
    25336: "Bellatrix",
    25428: "Elnath",
    25606: "Nihal",
    25930: "Mintaka",
    25985: "Arneb",
    26207: "Meissa",
    26241: "Hatysa",
    26311: "Alnilam",
    26380: "Bubup",
    26451: "Tianguan",
    26634: "Phact",
    26727: "Alnitak",
    27366: "Saiph",
    27628: "Wazn",
    27989: "Betelgeuse",
    28360: "Menkalinan",
    28380: "Mahasim",
    29034: "Elkurud",
    29550: "Amadioha",
    29655: "Propus",
    30122: "Furud",
    30324: "Mirzam",
    30343: "Tejat",
    30438: "Canopus",
    30860: "Lucilinburhuc",
    30905: "Lusitânia",
    31681: "Alhena",
    31685: "Pipit",
    31895: "Nosaxa",
    32246: "Mebsuta",
    32349: "Sirius",
    32362: "Alzirr",
    32916: "Nervia",
    33579: "Adhara",
    33719: "Citalá",
    33856: "Unurgunite",
    34045: "Muliphein",
    34088: "Mekbuda",
    34444: "Wezen",
    35550: "Wasat",
    35904: "Aludra",
    36188: "Gomeisa",
    36850: "Castor",
    37265: "Jishui",
    37279: "Procyon",
    37284: "Ceibo",
    37826: "Pollux",
    38041: "Tapecue",
    38170: "Azmidi",
    39429: "Naos",
    39757: "Tureis",
    39953: "Regor",  # not officially part of IAU recognized names
    40167: "Tegmine",
    40526: "Tarf",
    40687: "Násti",
    40881: "Piautos",
    41037: "Avior",
    41075: "Alsciaukat",
    41704: "Muscida",
    42402: "Minchir",
    42446: "Gakyid",
    42556: "Meleph",
    42806: "Asellus Borealis",
    42911: "Asellus Australis",
    42913: "Alsephina",
    43109: "Ashlesha",
    43587: "Copernicus",
    43674: "Stribor",
    44066: "Acubens",
    44127: "Talitha",
    44471: "Alkaphrah",
    44816: "Suhail",
    44946: "Nahn",
    45238: "Miaplacidus",
    45556: "Aspidiske",
    45941: "Markeb",
    46390: "Alphard",
    46471: "Intercrus",
    46750: "Alterf",
    47087: "Illyrian",
    47202: "Kalausi",
    47431: "Ukdah",
    47508: "Subra",
    48235: "Natasha",
    48356: "Zhang",
    48455: "Rasalas",
    48615: "Felis",
    48711: "Bibhā",
    49637: "Yunü (Yunu)",
    49669: "Regulus",
    50335: "Adhafera",
    50372: "Tania Borealis",
    50583: "Algieba",
    50801: "Tania Australis",
    51624: "Shaomin",
    52521: "Macondo",
    53229: "Praecipua",
    53721: "Chalawan",
    53740: "Alkes",
    53910: "Merak",
    54061: "Dubhe",
    54158: "Dingolay",
    54872: "Zosma",
    54879: "Chertan",
    55174: "Hunahpú",
    55203: "Alula Australis",
    55219: "Alula Borealis",
    55664: "Shama",
    56211: "Giausar",
    56508: "Formosa",
    56572: "Sagarmatha",
    57291: "Uklun",
    57370: "Flegetonte",
    57399: "Taiyangshou",
    57632: "Denebola",
    57757: "Zavijava",
    57820: "Aniara",
    58001: "Phecda",
    58952: "Tonatiuh",
    59199: "Alchiba",
    59747: "Imai",
    59774: "Megrez",
    59803: "Gienah",
    60129: "Zaniah",
    60260: "Ginan",
    60644: "Tupã",
    60718: "Acrux",
    60965: "Algorab",
    61084: "Gacrux",
    61177: "Funi",
    61317: "Chara",
    61359: "Kraz",
    61394: "Phyllon Kissinou",
    61941: "Porrima",
    62223: "La Superba",
    62423: "Tianyi",
    62434: "Mimosa",
    62956: "Alioth",
    63076: "Taiyi",
    63090: "Minelauva",
    63125: "Cor Caroli",
    63608: "Vindemiatrix",
    64241: "Diadem",
    65378: "Mizar",
    65474: "Spica",
    65477: "Alcor",
    66047: "Dofida",
    66192: "Liesma",
    66249: "Heze",
    67301: "Alkaid",
    67927: "Muphrid",
    68002: "Leepwal",
    68702: "Hadar",
    68756: "Thuban",
    68933: "Menkent",
    69427: "Kang",
    69673: "Arcturus",
    69701: "Syrma",
    69732: "Xuange",
    69974: "Khambalia",
    70755: "Elgafar",
    70890: "Proxima Centauri",
    71075: "Seginus",
    71681: "Toliman",
    71683: "Rigil Kentaurus",
    71860: "Uridim",
    72105: "Izar",
    72339: "Mönch",
    72487: "Merga",
    72607: "Kochab",
    72622: "Zubenelgenubi",
    72845: "Arcalís",
    73136: "Baekdu",
    73555: "Nekkar",
    73714: "Brachium",
    74785: "Zubeneschamali",
    74961: "Nikawiy",
    75097: "Pherkad",
    75411: "Alkalurops",
    75458: "Edasich",
    75695: "Nusakan",
    76267: "Alphecca",
    76333: "Zubenelhakrabi",
    76351: "Karaka",
    77070: "Unukalhai",
    77450: "Gudja",
    78104: "Iklil",
    78265: "Fang",
    78401: "Dschubba",
    78820: "Acrab",
    79043: "Marsic",
    79219: "Kamuy",
    79374: "Jabbah",
    79431: "Sharjah",
    79593: "Yed Prior",
    79882: "Yed Posterior",
    80112: "Alniyat",
    80331: "Athebyne",
    80463: "Cujam",
    80687: "Timir",
    80763: "Antares",
    80816: "Kornephoros",
    80838: "Ogma",
    80883: "Marfik",
    81022: "Rosaliadecastro",
    81266: "Paikauhale",
    82273: "Atria",
    82396: "Larawag",
    82514: "Xamidimura",
    82545: "Pipirima",
    82651: "Mahsati",
    83547: "Rapeto",
    83608: "Alrakis",
    83895: "Aldhibah",
    84012: "Sabik",
    84345: "Rasalgethi",
    84379: "Sarin",
    84405: "Guniibuu",
    84787: "Inquill",
    85670: "Rastaban",
    85693: "Maasym",
    85696: "Lesath",
    85822: "Yildun",
    85927: "Shaula",
    86032: "Rasalhague",
    86228: "Sargas",
    86614: "Dziban",
    86742: "Cebalrai",
    86782: "Alruba",
    86796: "Cervantes",
    87108: "Bake-eo (or Bake Eo)",
    87261: "Fuyue",
    87585: "Grumium",
    87833: "Eltanin",
    87937: "Barnard's Star",
    88414: "Pincoya",
    88635: "Alnasl",
    89341: "Polis",
    89931: "Kaus Media",
    90004: "Alasia",
    90185: "Kaus Australis",
    90344: "Fafnir",
    90496: "Kaus Borealis",
    91262: "Vega",
    91852: "Xihe",
    92420: "Sheliak",
    92761: "Ainalrami",
    92855: "Nunki",
    92895: "Kaveh",
    92946: "Alya",
    93194: "Sulafat",
    93506: "Ascella",
    93747: "Okab",
    94114: "Meridiana",
    94141: "Albaldah",
    94376: "Altais",
    94481: "Aladfar",
    94645: "Gumala",
    95124: "Belel",
    95241: "Arkab Prior",
    95262: "Sika",
    95294: "Arkab Posterior",
    95347: "Rukbat",
    95947: "Albireo",
    96078: "Uruk",
    96100: "Alsafi",
    96757: "Sham",
    97165: "Fawaris",
    97278: "Tarazed",
    97649: "Altair",
    97938: "Libertas",
    98036: "Alshain",
    98066: "Terebellum",
    98823: "Tianfu",
    99473: "Antinous",
    99711: "Phoenicia",
    99894: "Chechia",
    100064: "Algedi",
    100310: "Alshat",
    100345: "Dabih",
    100453: "Sadr",
    100751: "Peacock",
    101421: "Aldulfin",
    101769: "Rotanev",
    101958: "Sualocin",
    102098: "Deneb",
    102488: "Aljanah",
    102618: "Albali",
    103527: "Musica",
    104382: "Polaris Australis",
    104987: "Kitalpha",
    105199: "Alderamin",
    106032: "Alfirk",
    106278: "Sadalsuud",
    106786: "Bunda",
    106824: "Sāmaya",
    106985: "Nashira",
    107136: "Azelfafage",
    107251: "Bosona",
    107259: "Garnet Star",
    107315: "Enif",
    107556: "Deneb Algedi",
    108085: "Aldhanab",
    108375: "Itonda",
    108917: "Kurhah",
    109074: "Sadalmelik",
    109268: "Alnair",
    109427: "Biham",
    110003: "Ancha",
    110130: "Lang-Exster",
    110395: "Sadachbia",
    110813: "Lionrock",
    111169: "Stellio",
    111710: "Situla",
    112029: "Homam",
    112122: "Tiaki",
    112158: "Matar",
    112748: "Sadalbari",
    113136: "Skat",
    113288: "Tengshe",
    113357: "Helvetios",
    113368: "Fomalhaut",
    113881: "Scheat",
    113889: "Fumalsamakah",
    113963: "Markab",
    114322: "Ebla",
    115250: "Salm",
    115623: "Alkarab",
    116076: "Veritate",
    116084: "Poerava",
    116727: "Errai",
    118319: "Axólotl",
}
"""Star names by their HIP id. You can override these values when calling `stars()`"""


class StarCatalog:
    """Built-in star catalogs"""

    BIG_SKY_MAG11 = "big-sky-mag11"
    """
    [Big Sky Catalog](https://github.com/steveberardi/bigsky) ~ 370k stars up to magnitude 10
    
    This is an _abridged_ version of the Big Sky Catalog, including stars up to a limiting magnitude of 10 (total = 368,330 981,852).

    This catalog is included with Starplot, so does not require downloading any files.
    """

    BIG_SKY = "big-sky"
    """
    [Big Sky Catalog](https://github.com/steveberardi/bigsky) ~ 2.5M stars

    This is the full version of the Big Sky Catalog, which includes 2,557,500 stars from Hipparcos, Tycho-1, and Tycho-2.

    This catalog is very large (approx 100 MB), so it's not built-in to Starplot. When you plot stars and specify this catalog, the catalog 
    will be downloaded from the [Big Sky GitHub repository](https://github.com/steveberardi/bigsky) and saved to Starplot's data library 
    directory. You can override this download path with the environment variable `STARPLOT_DOWNLOAD_PATH`
    
    """


@cache
def table(catalog: StarCatalog = StarCatalog.BIG_SKY_MAG11, table_name="stars"):
    con = db.connect()

    if catalog == StarCatalog.BIG_SKY_MAG11:
        stars = con.read_parquet(DataFiles.BIG_SKY_MAG11, table_name=table_name)
    elif catalog == StarCatalog.BIG_SKY:
        bigsky.download_if_not_exists()
        stars = con.read_parquet(DataFiles.BIG_SKY, table_name=table_name)
    else:
        raise ValueError("Unrecognized star catalog.")

    designations = con.table("star_designations")

    stars = stars.mutate(
        epoch_year=2000,
        ra=_.ra_degrees,
        dec=_.dec_degrees,
        constellation_id=_.constellation,
        ra_hours=_.ra_degrees / 15,
        # stars parquet does not have geometry field
        geometry=_.ra_degrees.point(_.dec_degrees),
        rowid=ibis.row_number(),
        sk=ibis.row_number(),
    )

    stars = stars.join(
        designations,
        [
            stars.hip == designations.hip,
            (stars.ccdm.startswith("A")) | (stars.ccdm == "") | (stars.ccdm.isnull()),
        ],
        how="left",
    )

    return stars


def load(
    extent=None,
    catalog: StarCatalog = StarCatalog.BIG_SKY_MAG11,
    filters=None,
    sql=None,
):
    filters = filters or []
    stars = table(catalog)

    if extent:
        stars = stars.filter(stars.geometry.intersects(extent))

    if filters:
        stars = stars.filter(*filters)

    if sql:
        result = stars.alias("_").sql(sql).select("sk").execute()
        skids = result["sk"].to_list()
        stars = stars.filter(_.sk.isin(skids))

    return stars
